examples
========
Contrasting examples of the lucene api versus pythonic lupyne idioms.

indexers
---------
.. literalinclude:: ../examples/indexers.py

queries
---------
.. literalinclude:: ../examples/queries.py

searching
---------
.. literalinclude:: ../examples/searching.py

sorting
---------
.. literalinclude:: ../examples/sorting.py

server
---------
.. literalinclude:: ../examples/server.py
